@@ -12,7 +12,7 @@ from easy.permissions import (
     IsSuperUser,
 )
 from easy.response import BaseApiResponse
-from tests.demo_app.models import Event
+from tests.demo_app.models import Client, Event
 from tests.demo_app.schema import EventSchema
 from tests.demo_app.services import EventService
 
@@ -33,6 +33,16 @@ class AutoGenCrudAPIController(CrudAPIController):
         fields = ["__all__"]
 
 
+@api_controller("unittest", permissions=[BaseApiPermission])
+class AutoGenCrudSomeFieldsAPIController(CrudAPIController):
+    """
+    For unit testings of the no-m2m-fields model
+    """
+
+    class Meta:
+        model = Client
+
+
 @api_controller("unittest")
 class EasyCrudAPIController(CrudAPIController):
     """
@@ -68,10 +78,13 @@ class EasyCrudAPIController(CrudAPIController):
 
     @http_get(
         "/qs",
-        response=List[EventSchema],
     )
     async def list_events(self):
-        return await sync_to_async(list)(self.model.objects.all())
+        qs = await sync_to_async(self.model.objects.all)()
+        await sync_to_async(list)(qs)
+        if qs:
+            return qs
+        return BaseApiResponse()
 
 
 @api_controller("unittest")
